#!/bin/sh

# Setup script for multimedia configuration files.

# Copyright (C) 2011-2014  Simon Ruderich
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


set -eu

. ../lib.sh


# MPlayer and MPlayer2 use the same configuration directory.
if installed mplayer; then
    cleanup() {
        if test -h ~/.mplayer; then
            # Setup already done.
            return
        fi
        # Try to remove a default config file from ~/.mplayer. Necessary
        # because it's also created by mplayer --help.
        if test -f ~/.mplayer/config; then
            sha=`shasum ~/.mplayer/config | awk '{print $1}'`
            if test x"$sha" = x60f98ca2f1f3f81ce3ea2aa3e0e85e8c57e7db40; then
                rm ~/.mplayer/config
            else
                echo '~/.mplayer/config: found modifications, aborting' >&2
                exit 1
            fi
        fi
        rmdir ~/.mplayer 2>/dev/null || true
    }

    if mplayer --help | grep MPlayer2 >/dev/null; then
        cleanup
        link mplayer2 ~/.mplayer
    else
        cleanup
        link mplayer ~/.mplayer
    fi
fi
# Another MPlayer fork, but developed separately with a different config
# directory.
if installed mpv; then
    link mpv ~/.config/mpv
fi

if installed handbrake; then
    link handbrake ~/.config/ghb
fi
